# GRAPE: Grammatical Algorithms in Python for Evolution

[GRAPE](https://www.mdpi.com/2624-6120/3/3/39) is an implementation of Grammatical Evolution (GE) in [DEAP](https://deap.readthedocs.io/en/master/), an Evolutionary Computation framework in Python, 

How to cite:
```
Allan de Lima, Samuel Carvalho, Douglas Mota Dias, Enrique Naredo, Joseph P.
Sullivan, and Conor Ryan. 2022. GRAPE: Grammatical Algorithms in Python for
Evolution. Signals 3, 3 (2022), 642–663. https://doi.org/10.3390/signals3030039
```
